@@ -1,29 +1,34 @@
-import { Node } from "domhandler";
+import type { Node } from "domhandler";
 import { hasChildren } from "./tagtypes";
 
 /**
  * Given an array of nodes, remove any member that is contained by another.
  *
  * @param nodes Nodes to filter.
+ * @returns Remaining nodes that aren't subtrees of each other.
  */
 export function removeSubsets(nodes: Node[]): Node[] {
     let idx = nodes.length;
 
-    // Check if each node (or one of its ancestors) is already contained in the
-    // array.
+    /*
+     * Check if each node (or one of its ancestors) is already contained in the
+     * array.
+     */
     while (--idx >= 0) {
         const node = nodes[idx];
 
-        // Remove the node if it is not unique.
-        // We are going through the array from the end, so we only
-        // have to check nodes that preceed the node under consideration in the array.
+        /*
+         * Remove the node if it is not unique.
+         * We are going through the array from the end, so we only
+         * have to check nodes that preceed the node under consideration in the array.
+         */
         if (idx > 0 && nodes.lastIndexOf(node, idx - 1) >= 0) {
             nodes.splice(idx, 1);
             continue;
         }
 
         for (let ancestor = node.parent; ancestor; ancestor = ancestor.parent) {
-            if (nodes.indexOf(ancestor) > -1) {
+            if (nodes.includes(ancestor)) {
                 nodes.splice(idx, 1);
                 break;
             }
@@ -42,11 +47,11 @@ export const enum DocumentPosition {
     CONTAINED_BY = 16,
 }
 
-/***
+/**
  * Compare the position of one node against another node in any other document.
  * The return value is a bitmask with the following values:
  *
- * document order:
+ * Document order:
  * > There is an ordering, document order, defined on all the nodes in the
  * > document corresponding to the order in which the first character of the
  * > XML representation of each node occurs in the XML representation of the
@@ -59,13 +64,13 @@ export const enum DocumentPosition {
  *
  * Source:
  * http://www.w3.org/TR/DOM-Level-3-Core/glossary.html#dt-document-order
- * @param nodaA The first node to use in the comparison
+ *
+ * @param nodeA The first node to use in the comparison
  * @param nodeB The second node to use in the comparison
+ * @returns A bitmask describing the input nodes' relative position.
  *
- * @return A bitmask describing the input nodes' relative position.
- *
- *        See http://dom.spec.whatwg.org/#dom-node-comparedocumentposition for
- *        a description of these values.
+ * See http://dom.spec.whatwg.org/#dom-node-comparedocumentposition for
+ * a description of these values.
  */
 export function compareDocumentPosition(nodeA: Node, nodeB: Node): number {
     const aParents = [];
@@ -86,8 +91,9 @@ export function compareDocumentPosition(nodeA: Node, nodeB: Node): number {
         current = current.parent;
     }
 
+    const maxIdx = Math.min(aParents.length, bParents.length);
     let idx = 0;
-    while (aParents[idx] === bParents[idx]) {
+    while (idx < maxIdx && aParents[idx] === bParents[idx]) {
         idx++;
     }
 
@@ -105,21 +111,20 @@ export function compareDocumentPosition(nodeA: Node, nodeB: Node): number {
             return DocumentPosition.FOLLOWING | DocumentPosition.CONTAINED_BY;
         }
         return DocumentPosition.FOLLOWING;
-    } else {
-        if (sharedParent === nodeA) {
-            return DocumentPosition.PRECEDING | DocumentPosition.CONTAINS;
-        }
-        return DocumentPosition.PRECEDING;
     }
+    if (sharedParent === nodeA) {
+        return DocumentPosition.PRECEDING | DocumentPosition.CONTAINS;
+    }
+    return DocumentPosition.PRECEDING;
 }
 
-/***
+/**
  * Sort an array of nodes based on their relative position in the document and
  * remove any duplicate nodes. If the array contains nodes that do not belong
  * to the same document, sort order is unspecified.
  *
- * @param nodes Array of DOM nodes
- * @returns collection of unique nodes, sorted in document order
+ * @param nodes Array of DOM nodes.
+ * @returns Collection of unique nodes, sorted in document order.
  */
 export function uniqueSort(nodes: Node[]): Node[] {
     nodes = nodes.filter((node, i, arr) => !arr.includes(node, i + 1));
