@@ -1,11 +1,11 @@
-import { Node, Element } from "domhandler";
+import type { Node, Element } from "domhandler";
 
-/***
+/**
  * Remove an element from the dom
  *
  * @param elem The element to be removed
  */
-export function removeElement(elem: Node) {
+export function removeElement(elem: Node): void {
     if (elem.prev) elem.prev.next = elem.next;
     if (elem.next) elem.next.prev = elem.prev;
 
@@ -15,13 +15,13 @@ export function removeElement(elem: Node) {
     }
 }
 
-/***
+/**
  * Replace an element in the dom
  *
  * @param elem The element to be replaced
  * @param replacement The element to be added
  */
-export function replaceElement(elem: Node, replacement: Node) {
+export function replaceElement(elem: Node, replacement: Node): void {
     const prev = (replacement.prev = elem.prev);
     if (prev) {
         prev.next = replacement;
@@ -39,30 +39,36 @@ export function replaceElement(elem: Node, replacement: Node) {
     }
 }
 
-/***
- * Append a child to an element
+/**
+ * Append a child to an element.
  *
- * @param elem The element to append to
- * @param child The element to be added as a child
+ * @param elem The element to append to.
+ * @param child The element to be added as a child.
  */
-export function appendChild(elem: Element, child: Node) {
+export function appendChild(elem: Element, child: Node): void {
+    removeElement(child);
+
+    child.next = null;
     child.parent = elem;
 
-    if (elem.children.push(child) !== 1) {
+    if (elem.children.push(child) > 1) {
         const sibling = elem.children[elem.children.length - 2];
         sibling.next = child;
         child.prev = sibling;
-        child.next = null;
+    } else {
+        child.prev = null;
     }
 }
 
-/***
- * Append an element after another
+/**
+ * Append an element after another.
  *
- * @param elem The element to append to
- * @param next The element be added
+ * @param elem The element to append after.
+ * @param next The element be added.
  */
-export function append(elem: Node, next: Node) {
+export function append(elem: Node, next: Node): void {
+    removeElement(next);
+
     const { parent } = elem;
     const currNext = elem.next;
 
@@ -82,17 +88,40 @@ export function append(elem: Node, next: Node) {
     }
 }
 
-/***
- * Prepend an element before another
+/**
+ * Prepend a child to an element.
  *
- * @param elem The element to append to
- * @param prev The element be added
+ * @param elem The element to prepend before.
+ * @param child The element to be added as a child.
  */
-export function prepend(elem: Node, prev: Node) {
+export function prependChild(elem: Element, child: Node): void {
+    removeElement(child);
+
+    child.parent = elem;
+    child.prev = null;
+
+    if (elem.children.unshift(child) !== 1) {
+        const sibling = elem.children[1];
+        sibling.prev = child;
+        child.next = sibling;
+    } else {
+        child.next = null;
+    }
+}
+
+/**
+ * Prepend an element before another.
+ *
+ * @param elem The element to prepend before.
+ * @param prev The element be added.
+ */
+export function prepend(elem: Node, prev: Node): void {
+    removeElement(prev);
+
     const { parent } = elem;
     if (parent) {
         const childs = parent.children;
-        childs.splice(childs.lastIndexOf(elem), 0, prev);
+        childs.splice(childs.indexOf(elem), 0, prev);
     }
 
     if (elem.prev) {
