@@ -1,7 +1,13 @@
-import { Node } from "domhandler";
+import type { Node } from "domhandler";
 import { isTag, isCDATA, isText, hasChildren } from "./tagtypes";
 import renderHTML, { DomSerializerOptions } from "dom-serializer";
 
+/**
+ * @param node Node to get the outer HTML of.
+ * @param options Options for serialization.
+ * @deprecated Use the `dom-serializer` module directly.
+ * @returns `node`'s outer HTML.
+ */
 export function getOuterHTML(
     node: Node | Node[],
     options?: DomSerializerOptions
@@ -9,6 +15,12 @@ export function getOuterHTML(
     return renderHTML(node, options);
 }
 
+/**
+ * @param node Node to get the inner HTML of.
+ * @param options Options for serialization.
+ * @deprecated Use the `dom-serializer` module directly.
+ * @returns `node`'s inner HTML.
+ */
 export function getInnerHTML(
     node: Node,
     options?: DomSerializerOptions
@@ -18,6 +30,12 @@ export function getInnerHTML(
         : "";
 }
 
+/**
+ * Get a node's inner text.
+ *
+ * @param node Node to get the inner text of.
+ * @returns `node`'s inner text.
+ */
 export function getText(node: Node | Node[]): string {
     if (Array.isArray(node)) return node.map(getText).join("");
     if (isTag(node)) return node.name === "br" ? "\n" : getText(node.children);
